// Topic controller.
(function($) {
	$.widget('adsk.topiccontroller', {
		options: {
		    defaultTopicHref: undefined,
		    shareController: undefined,
            favoritesController: undefined,
		    pageIds: ['navigation', 'search', 'page', 'share'],
		    toc: undefined,
		    orientationData: undefined
		},

        /* Private members. */

		_view: undefined,
		_defaultTopicData: undefined,
		_currentTopicData: undefined,
		_parentTopicData: undefined,

		_siblingTopicData: {
		    prn: undefined, // previous
		    nxn: undefined // next
		},

        // This method is the widget's constructor.
		_create: function() {
            console.log('topiccontroller: _create');

            // Create view and attach event handlers.
            $('#topic').topicview({
                create:     $.proxy(this._viewCreateHandler, this),
                buttontap:  $.proxy(this._viewButtontapHandler, this),
                swipeleft:  $.proxy(this._viewSwipeLeftHandler, this),
                swiperight: $.proxy(this._viewSwipeRightHandler, this),
                opentopic:  $.proxy(this._viewOpentopicHandler, this)
            });
		},

		_viewOpentopicHandler: function(event, data) {
		    console.log('topiccontroller: _viewOpentopicHandler');

		    this._trigger('opentopic', {}, data);
		},

        // View widget 'create' event handler.
		_viewCreateHandler: function(event, ui) {
            console.log('topiccontroller: _viewCreateHandler');

            this._view = $(event.target).topicview("instance");
		},

		_openDefaultTopic: function(defaultTopic) {
		    console.log('topiccontroller: _openDefaultTopic');

            this._trigger('opentopic', {}, {
                href: defaultTopic.attr.href
            });
		},

		_getDefaultTopicData: function() {
		    console.log('topiccontroller: _getDefaultTopicData');

		    var href = this.options.defaultTopicHref;

            var topic = this._fetchTopicData({
                href: href
            });

            // If no topic specified in TOC tree data,
            // use config provided HREF to load default topic.
            if (topic === undefined) {
                topic = {
                    /* TODO: add default topic title into publication config. */
                    data: undefined,
                    attr: {
                        href: href
                    }
                };
            }

            return topic;
		},

        // Disable/enable navigation buttons and favorites.
		_setupTopicRelatedFeatures: function(topic) {
		    console.log('topiccontroller: _setupTopicRelatedFeatures');

            var toc = this.options.toc,
            	view = this._view;

		    if (topic !== undefined && topic.attr.id !== undefined) {
                this._setupGoBackFeature(view);

                this._setupGoToParentFeature(toc, topic, view);
                this._setupGoToSiblingFeature('prn', toc, topic, view);
                this._setupGoToSiblingFeature('nxn', toc, topic, view);

                this._setupFavoritesFeature(topic, view);
                // TODO: prev and next features.
		    } else {
		        this._disableTopicRelatedFeatures(view);
		    }

		},

		_disableTopicRelatedFeatures: function(view) {
		    console.log('topiccontroller: _disableTopicRelatedFeatures');

		    view.initGoToParentButton(false);
            view.initFavoritesButton(false);
            view.initGoBackButton(false);

            this._siblingTopicData['prn'] = undefined;
            this._siblingTopicData['nxn'] = undefined;

            view.flag(false);
		},

		_setupGoBackFeature: function(view) {
		     console.log('topiccontroller: _setupGoBackFeature');

             view.initGoBackButton(history.length > 0);
		},


		_setupGoToParentFeature: function(toc, topic, view) {
		    console.log('topiccontroller: _setupGoToParentFeature');

		    // Enable "Go to parent" button if parent topic available.
		    var parentTopic = undefined;

            if (toc !== undefined) {
                var parentTopicNumber = topic.attr.pn,
                    bookName = "";

                if (parentTopicNumber !== undefined) {
                    parentTopic = toc.tocIndexedByTopicNumber[bookName][parentTopicNumber]
                }

                var goToParentButtonEnabled = (parentTopic !== undefined) ? true: false;

                if (goToParentButtonEnabled) {
                    this._parentTopicData = parentTopic;
                } else {
                    this._parentTopicData = undefined;
                }

                view.initGoToParentButton(goToParentButtonEnabled);
            } else {
                view.initGoToParentButton(false);
            }
		},


		// attr = prn || nxn.
		_setupGoToSiblingFeature: function(attr, toc, topic, view) {
		    console.log('topiccontroller: _setupGoToSiblingFeature');

		    // Enable "GoTo" button if 'previous/next' topic available.
		    var targetTopic = undefined;

            if (toc !== undefined) {
                var topicNumber = topic.attr[attr],
                    bookName = '';

                if (topicNumber !== undefined) {
                    targetTopic = toc.tocIndexedByTopicNumber[bookName][topicNumber];
                }
            }

            this._siblingTopicData[attr] = targetTopic;
		},

		_setupFavoritesFeature: function(topic, view) {
		    console.log('topiccontroller: _setupFavoritesFeature');

		    view.initFavoritesButton(true);

		    // Indicate if opened topic page is in favorites.
            var isTopicInFavorites = this.options.favoritesController.isTopicIdInFavorites(topic.attr.id);
            view.flag(isTopicInFavorites);
		},

		_isPageId: function(id) {
            return ($.inArray(id, this.options.pageIds) > -1);
		},

		_makePageCurrentById: function(id) {
		    console.log('topiccontroller: _makePageCurrentById, id = ', id);

		    if (this._isPageId(id)) {
                this._trigger('showpage', {}, { id: id });
            }
		},

		_createShareController: function() {
		    console.log('topiccontroller: _createShareController');

            this.options.shareController = $.adsk.sharecontroller({
                back:               $.proxy(this._backToPreviousPage, this),
                shareButtonOffset:  this.getShareButtonOffset(),
                orientationData:    this.options.orientationData
            });
		},

		_viewButtontapHandler: function(event, id) {
		    console.log('topiccontroller: _viewButtontapHandler');

            id = id.substring('topic-'.length);
            var handlerName = '_' + id + 'ButtontapHandler';
            this[handlerName](event, id);
		},

        _setTopicTitleToShare: function(title){
            console.log('topiccontroller: _setTopicTitleToShare', title);

            if (this.options.shareController !== undefined) {
                this.options.shareController._setCurrentTopicTitle(title);
            }
        },

		_shareButtontapHandler: function(event, id) {
		    // Create share controller lazily.
		    var controller = this.options.shareController;

		    if (controller === undefined) {
                this._createShareController();
                controller = this.options.shareController;
            }

            this._makePageCurrentById(id);
            this._setTopicTitleToShare(this._currentTopicData.data);
            controller.refresh(this.getShareButtonOffset());
		},

		_parentButtontapHandler: function(event, id) {
		    var parentTopic = this._parentTopicData;

            if (parentTopic !== undefined) {
                this._currentTopicData = parentTopic;

                this._trigger('opentopic', {}, {
                    href: parentTopic.attr.href
                });
            }
		},

		_favoritesButtontapHandler: function(event, id) {
		    var attr = this._currentTopicData.attr;
		    if (attr.id !== undefined) {
                var added = this.options.favoritesController.addOrRemoveFavoriteTopicId(attr.id);
                this._view.flag(added);
            }
		},

		_navigationButtontapHandler: function(event, id) {
		    console.log('topiccontroller: _navigationButtontapHandler');

		    this._makePageCurrentById(id);
		},

		_backButtontapHandler: function() {
		    console.log('topiccontroller: _backButtonHandler');

		    history.go(-1);
		},

		_homeButtontapHandler: function(event, id) {
		    console.log('topiccontroller: _homeButtontapHandler');

            this._openDefaultTopic(this._defaultTopicData);
		},

		_searchButtontapHandler: function(event, id) {
            console.log('topiccontroller: _searchButtontapHandler');

            this._makePageCurrentById(id);

            this._trigger('setsuggestiondata', {}, [this._getTopicSearchData()]);
        },

        _viewSwipeRightHandler: function(event) {
            console.log('topiccontroller: _viewSwipeRightHandler');

            var prevTopic = this._siblingTopicData['prn'];

            if (prevTopic !== undefined) {
                this._currentTopicData = prevTopic;

                this._trigger('opentopic', {}, {
                    href: prevTopic.attr.href
                });
            }
        },

        _viewSwipeLeftHandler: function(event) {
            console.log('topiccontroller: _viewSwipeLeftHandler');

            var nextTopic = this._siblingTopicData['nxn'];

            if (nextTopic !== undefined) {
                this._currentTopicData = nextTopic;

                this._trigger('opentopic', {}, {
                    href: nextTopic.attr.href
                });
            }
        },

        _getTopicSearchData: function(){
            console.log('topiccontroller: _getTopicSearchData');

            return {data: document.getElementById('body-content'),
                    type: 'topic'};
        },

        // Tells the view to load topic if it is specified.
		_showTopicContent: function(topic) {
            console.log('topiccontroller: _showTopicContent, ', topic);

            if (topic !== undefined) {
                console.log('topic data: ', topic);

                var href = topic.attr.href,
                    title = topic.data;

                // Get book name to resolve inner links.
                var bookBase = this._getBookBase(href);

                this._setTopicTitleToShare(title);
                this._view.loadPage(href, title, bookBase);
            }
        },

        // Get topic data (title, href, id etc.) from TOC tree by ID, HREF or topic number.
		_fetchTopicData: function(data) {
		    console.log('topiccontroller: _fetchTopicData');

            var toc = this.options.toc,
                bookName = '',
                topic = undefined;

            if (toc !== undefined) {
                // Get topic data by topic ID.
                if (data.id !== undefined && data.id !== '') {
                    if (toc.tocIndexedById !== undefined) {
                        topic = toc.tocIndexedById[bookName][data.id];
                    }
                // Get topic data by href.
                } else if (data.href !== undefined && data.href !== '') {
                    // Crop url fragment.
                    var href = data.href;
                    if (data.href.lastIndexOf('#') != -1) {
                        href = data.href.substr(0, data.href.lastIndexOf('#'));
                    }

                    if (toc.tocIndexedByHref !== undefined) {
                        topic = toc.tocIndexedByHref[bookName][href];
                    }
                // Get topic data by topic number.
                } else if (data.tn !== undefined && data.tn !== '') {
                    if (toc.tocIndexedByTopicNumber !== undefined) {
                        topic = toc.tocIndexedByTopicNumber[bookName][data.tn];
                    }
                }
            }

            if (topic === undefined) {
                topic = {
                    attr: {
                        href: data.href
                    }
                };
            } else {
                topic.attr.href = data.href; // Preserve url fragment.
            }

            return topic;
		},

		_backToPreviousPage: function() {
            console.log('topiccontroller: _backToPreviousPage');

            this._trigger('back');
        },

        // Get book name from path.
        // ./filesTEST1/topichead.htm => TEST1
        _getBookBase: function(path) {
            var pos = path.lastIndexOf('/'),
                base = path.substring(0, pos + 1);

            return base;
        },

        _getBookName: function(bookBase) {
            var files = '/files',
                startIndex = bookBase.lastIndexOf(files) + files.length,
                endIndex = bookBase.lastIndexOf('/');

            return bookBase.substring(startIndex, endIndex);
        },

		/* Public members. */

        resize: function(data) {
            console.log('topiccontroller: resize');

            this.options.orientationData = data;

            this._view.resize();

            var controller = this.options.shareController;
            if (controller !== undefined) {
                controller.resize(data);
                controller.refresh(this.getShareButtonOffset());
            }
        },

        setTocData: function(data) {
            console.log('topiccontroller: setTocData, ');

            this.options.toc = data;

            // Try to fetch default topic data again.
            this._defaultTopicData = this._getDefaultTopicData();
        },

		openTopic: function(data) {
		    console.log('topiccontroller: openTopic: ', data);

            if (data === undefined || $.isEmptyObject(data)) {
                return;
            }

		    var topic = this._currentTopicData = this._fetchTopicData(data);

		    this._showTopicContent(topic);
		    this._setupTopicRelatedFeatures(topic);
		},

		getShareButtonOffset: function() {
            console.log('topiccontroller: getShareButtonOffset');

            return this._view.getShareButtonOffset();
        }
	});
})(jQuery);
// SIG // Begin signature block
// SIG // MIIZfQYJKoZIhvcNAQcCoIIZbjCCGWoCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // ZNeqXaznveTUyb4BWTeZwLpse+f6/8bZbbv7BhFkGcCg
// SIG // ggoaMIIEyzCCA7OgAwIBAgIQCQja65wGHi65un4mqmKH
// SIG // ijANBgkqhkiG9w0BAQsFADCBhDELMAkGA1UEBhMCVVMx
// SIG // HTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMR8w
// SIG // HQYDVQQLExZTeW1hbnRlYyBUcnVzdCBOZXR3b3JrMTUw
// SIG // MwYDVQQDEyxTeW1hbnRlYyBDbGFzcyAzIFNIQTI1NiBD
// SIG // b2RlIFNpZ25pbmcgQ0EgLSBHMjAeFw0xOTA1MTQwMDAw
// SIG // MDBaFw0yMDA1MTMyMzU5NTlaMHwxCzAJBgNVBAYTAlVT
// SIG // MRMwEQYDVQQIDApDYWxpZm9ybmlhMRMwEQYDVQQHDApT
// SIG // YW4gUmFmYWVsMRcwFQYDVQQKDA5BdXRvZGVzaywgSW5j
// SIG // LjERMA8GA1UECwwIU2VjdXJpdHkxFzAVBgNVBAMMDkF1
// SIG // dG9kZXNrLCBJbmMuMIIBIjANBgkqhkiG9w0BAQEFAAOC
// SIG // AQ8AMIIBCgKCAQEAkVKRoPYsoxPdlabspcuG8HYDfcWQ
// SIG // 9qyPOT2punwpVdjt2slktcpSTlydrGy8ijcbl5/k8AOJ
// SIG // afKMQvow0fNjIoNB5nsb8j2xFJPbBhHl8GT4P6DZ1OWK
// SIG // ioiUXgGHKjctUws49J4elntqvBYhKCbuPqG772QCoYFU
// SIG // P7qcFbh3PbyNB6cnKMn2vNGRqiEtV2aGg+/MiL3QPsvT
// SIG // kTWhVuTLIvwZ4kK5C5ACiQzlGOlE+C7gWuFoxtvy6gUa
// SIG // A8JAq/xLjYKwFevQwGncg3s1cuiGhx0P7Rvn6oCd2cem
// SIG // FmbK3I3rMRt+jc9wzAj3oHxvCo4f5Lfva+OpC1dETUVV
// SIG // sk0VGwIDAQABo4IBPjCCATowCQYDVR0TBAIwADAOBgNV
// SIG // HQ8BAf8EBAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwMw
// SIG // YQYDVR0gBFowWDBWBgZngQwBBAEwTDAjBggrBgEFBQcC
// SIG // ARYXaHR0cHM6Ly9kLnN5bWNiLmNvbS9jcHMwJQYIKwYB
// SIG // BQUHAgIwGQwXaHR0cHM6Ly9kLnN5bWNiLmNvbS9ycGEw
// SIG // HwYDVR0jBBgwFoAU1MAGIknrOUvdk+JcobhHdglyA1gw
// SIG // KwYDVR0fBCQwIjAgoB6gHIYaaHR0cDovL3JiLnN5bWNi
// SIG // LmNvbS9yYi5jcmwwVwYIKwYBBQUHAQEESzBJMB8GCCsG
// SIG // AQUFBzABhhNodHRwOi8vcmIuc3ltY2QuY29tMCYGCCsG
// SIG // AQUFBzAChhpodHRwOi8vcmIuc3ltY2IuY29tL3JiLmNy
// SIG // dDANBgkqhkiG9w0BAQsFAAOCAQEA0Q2+iVSEfT4xGq3A
// SIG // OADVb0rT5Z8E+PPb1x6hKknSzuaZKk/acDz9mdnFajaU
// SIG // WgIKiFJlsqJnuAM1w4lqKaEWsz3DoxvGIEwexj71Ud6a
// SIG // KlBJNcR9DdkXUZwMhbw9d78rjJAIX6tOwfSludZfdq8b
// SIG // YEkuIzQi9uYW9vHVPSCzhnUBKjwc9qTo9yBc7Fcn4FAT
// SIG // 90DzWM2hS9oc3p0pprYI2I/O4th90BEmwWkVqVgfaR0z
// SIG // VyIEmBbqB/IWLfjUBZJ/8sbkwWuWlYVRrfPxsj1e9qvb
// SIG // wE3Y28jWyGbqoUG39GhXk3uT8R8i3+T6M0c4rMfdifBC
// SIG // pceCaFTJzSye7LoeVzCCBUcwggQvoAMCAQICEHwbNTVK
// SIG // 59t050FfEWnKa6gwDQYJKoZIhvcNAQELBQAwgb0xCzAJ
// SIG // BgNVBAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5j
// SIG // LjEfMB0GA1UECxMWVmVyaVNpZ24gVHJ1c3QgTmV0d29y
// SIG // azE6MDgGA1UECxMxKGMpIDIwMDggVmVyaVNpZ24sIElu
// SIG // Yy4gLSBGb3IgYXV0aG9yaXplZCB1c2Ugb25seTE4MDYG
// SIG // A1UEAxMvVmVyaVNpZ24gVW5pdmVyc2FsIFJvb3QgQ2Vy
// SIG // dGlmaWNhdGlvbiBBdXRob3JpdHkwHhcNMTQwNzIyMDAw
// SIG // MDAwWhcNMjQwNzIxMjM1OTU5WjCBhDELMAkGA1UEBhMC
// SIG // VVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9u
// SIG // MR8wHQYDVQQLExZTeW1hbnRlYyBUcnVzdCBOZXR3b3Jr
// SIG // MTUwMwYDVQQDEyxTeW1hbnRlYyBDbGFzcyAzIFNIQTI1
// SIG // NiBDb2RlIFNpZ25pbmcgQ0EgLSBHMjCCASIwDQYJKoZI
// SIG // hvcNAQEBBQADggEPADCCAQoCggEBANeVQ9Tc32euOftS
// SIG // pLYmMQRw6beOWyq6N2k1lY+7wDDnhthzu9/r0XY/ilaO
// SIG // 6y1L8FcYTrGNpTPTC3Uj1Wp5J92j0/cOh2W13q0c8fU1
// SIG // tCJRryKhwV1LkH/AWU6rnXmpAtceSbE7TYf+wnirv+9S
// SIG // rpyvCNk55ZpRPmlfMBBOcWNsWOHwIDMbD3S+W8sS4duM
// SIG // xICUcrv2RZqewSUL+6McntimCXBx7MBHTI99w94Zzj7u
// SIG // BHKOF9P/8LIFMhlM07Acn/6leCBCcEGwJoxvAMg6ABFB
// SIG // ekGwp4qRBKCZePR3tPNgKuZsUAS3FGD/DVH0qIuE/iHa
// SIG // XF599Sl5T7BEdG9tcv8CAwEAAaOCAXgwggF0MC4GCCsG
// SIG // AQUFBwEBBCIwIDAeBggrBgEFBQcwAYYSaHR0cDovL3Mu
// SIG // c3ltY2QuY29tMBIGA1UdEwEB/wQIMAYBAf8CAQAwZgYD
// SIG // VR0gBF8wXTBbBgtghkgBhvhFAQcXAzBMMCMGCCsGAQUF
// SIG // BwIBFhdodHRwczovL2Quc3ltY2IuY29tL2NwczAlBggr
// SIG // BgEFBQcCAjAZGhdodHRwczovL2Quc3ltY2IuY29tL3Jw
// SIG // YTA2BgNVHR8ELzAtMCugKaAnhiVodHRwOi8vcy5zeW1j
// SIG // Yi5jb20vdW5pdmVyc2FsLXJvb3QuY3JsMBMGA1UdJQQM
// SIG // MAoGCCsGAQUFBwMDMA4GA1UdDwEB/wQEAwIBBjApBgNV
// SIG // HREEIjAgpB4wHDEaMBgGA1UEAxMRU3ltYW50ZWNQS0kt
// SIG // MS03MjQwHQYDVR0OBBYEFNTABiJJ6zlL3ZPiXKG4R3YJ
// SIG // cgNYMB8GA1UdIwQYMBaAFLZ3+mlIR59TEtXC6gcydgfR
// SIG // lwcZMA0GCSqGSIb3DQEBCwUAA4IBAQB/68qn6ot2Qus+
// SIG // jiBUMOO3udz6SD4Wxw9FlRDNJ4ajZvMC7XH4qsJVl5Fw
// SIG // g/lSflJpPMnx4JRGgBi7odSkVqbzHQCR1YbzSIfgy8Q0
// SIG // aCBetMv5Be2cr3BTJ7noPn5RoGlxi9xR7YA6JTKfRK9u
// SIG // QyjTIXW7l9iLi4z+qQRGBIX3FZxLEY3ELBf+1W5/muJW
// SIG // kvGWs60t+fTf2omZzrI4RMD3R3vKJbn6Kmgzm1By3qif
// SIG // 1M0sCzS9izB4QOCNjicbkG8avggVgV3rL+JR51EeyXgp
// SIG // 5x5lvzjvAUoBCSQOFsQUecFBNzTQPZFSlJ3haO8I8OJp
// SIG // nGdukAsak3HUJgLDwFojMYIOuzCCDrcCAQEwgZkwgYQx
// SIG // CzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBD
// SIG // b3Jwb3JhdGlvbjEfMB0GA1UECxMWU3ltYW50ZWMgVHJ1
// SIG // c3QgTmV0d29yazE1MDMGA1UEAxMsU3ltYW50ZWMgQ2xh
// SIG // c3MgMyBTSEEyNTYgQ29kZSBTaWduaW5nIENBIC0gRzIC
// SIG // EAkI2uucBh4uubp+Jqpih4owDQYJYIZIAWUDBAIBBQCg
// SIG // fDAQBgorBgEEAYI3AgEMMQIwADAZBgkqhkiG9w0BCQMx
// SIG // DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYK
// SIG // KwYBBAGCNwIBFTAvBgkqhkiG9w0BCQQxIgQgXToiqdff
// SIG // TYSg5doeDUSLFncEa+DC1IqJ0G44lsYAnEIwDQYJKoZI
// SIG // hvcNAQEBBQAEggEARnvM5wi07qVq9lpxBLZCRKFoEknx
// SIG // PHlUg934b5WubWlPZ9AHEHNDCQ6qmx3VmqLGSeZM8t2z
// SIG // CtiTcvgoHlOosooLMlHuoe1U47SxBvQ2+UQvfhZUl6gu
// SIG // kX4VD3Juwxca0+OiyKQlyMjsZ6oEbfA9HnKZLWbumEcc
// SIG // xQfImxegMugcozsEVJj0WiNBu5x98lEhBcPyg3HZCGah
// SIG // sdQZXyOUfEPnUnBIrv5YApv2tR2zjTZErmb02FusYoAt
// SIG // 4/i1Zn/+aL/8snBIOQNq5cshOgcm45t8ovmu8tS3aswc
// SIG // BlKoaC/acabDim+cCsuWxFcOLGAhrfVnCKNBKNrc/8Ba
// SIG // Yf2p2aGCDHQwggxwBgorBgEEAYI3AwMBMYIMYDCCDFwG
// SIG // CSqGSIb3DQEHAqCCDE0wggxJAgEDMQ8wDQYJYIZIAWUD
// SIG // BAIBBQAwga8GCyqGSIb3DQEJEAEEoIGfBIGcMIGZAgEB
// SIG // BgkrBgEEAaAyAgMwMTANBglghkgBZQMEAgEFAAQggToY
// SIG // PNEuMN9rOIMR0b3mR1D5ZnECzjsUdOHciCkOUrMCFE1y
// SIG // 6wcRKiyBXt4i6Mo6XPIqXhAIGA8yMDIwMDIwNzE2MTcx
// SIG // MFqgL6QtMCsxKTAnBgNVBAMMIEdsb2JhbFNpZ24gVFNB
// SIG // IGZvciBBZHZhbmNlZCAtIEcyoIII0zCCBLYwggOeoAMC
// SIG // AQICDAynz10HBySsieeaOjANBgkqhkiG9w0BAQsFADBb
// SIG // MQswCQYDVQQGEwJCRTEZMBcGA1UEChMQR2xvYmFsU2ln
// SIG // biBudi1zYTExMC8GA1UEAxMoR2xvYmFsU2lnbiBUaW1l
// SIG // c3RhbXBpbmcgQ0EgLSBTSEEyNTYgLSBHMjAeFw0xODAy
// SIG // MTkwMDAwMDBaFw0yOTAzMTgxMDAwMDBaMCsxKTAnBgNV
// SIG // BAMMIEdsb2JhbFNpZ24gVFNBIGZvciBBZHZhbmNlZCAt
// SIG // IEcyMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKC
// SIG // AQEAt8eSiijY85HLUA1d6ylEwYJZpcpkzr2DtVHllMxu
// SIG // gJoXbNz/YuY2Q14Bwgxkjcp3nvZdd0W5Xsgk60E3EWY3
// SIG // rMjNdJvMs+9M4n8bznO+yZadNR5891T3bOygEtaumZ1j
// SIG // xHhfWakuIvXDJ9iyW0VjJ5D/jLE9qbTzDsDxIGUGiZ0D
// SIG // HKOwUkGFNOu8y85U9hL+swGJSqb6VMUf+9McwOO/l+M/
// SIG // 0Bv5QMcb1esmfEMwx3DyeBGqhU6lDg0ASjoRd6PKIwGA
// SIG // nsiTVl1GzIrY0qoKhIWyiVvVMs5BexhOVMqr0VJeEtMk
// SIG // nlbzDI/dvZKOedVBicOjoOWR/MdnnYczznEycwIDAQAB
// SIG // o4IBqDCCAaQwDgYDVR0PAQH/BAQDAgeAMEwGA1UdIARF
// SIG // MEMwQQYJKwYBBAGgMgEeMDQwMgYIKwYBBQUHAgEWJmh0
// SIG // dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRv
// SIG // cnkvMAkGA1UdEwQCMAAwFgYDVR0lAQH/BAwwCgYIKwYB
// SIG // BQUHAwgwRgYDVR0fBD8wPTA7oDmgN4Y1aHR0cDovL2Ny
// SIG // bC5nbG9iYWxzaWduLmNvbS9ncy9nc3RpbWVzdGFtcGlu
// SIG // Z3NoYTJnMi5jcmwwgZgGCCsGAQUFBwEBBIGLMIGIMEgG
// SIG // CCsGAQUFBzAChjxodHRwOi8vc2VjdXJlLmdsb2JhbHNp
// SIG // Z24uY29tL2NhY2VydC9nc3RpbWVzdGFtcGluZ3NoYTJn
// SIG // Mi5jcnQwPAYIKwYBBQUHMAGGMGh0dHA6Ly9vY3NwMi5n
// SIG // bG9iYWxzaWduLmNvbS9nc3RpbWVzdGFtcGluZ3NoYTJn
// SIG // MjAdBgNVHQ4EFgQULW5u0Y3lA4Du52Ppp9naCzxXIj0w
// SIG // HwYDVR0jBBgwFoAUkiGnSpVdZLCbtB7mADdH5p1BK0ww
// SIG // DQYJKoZIhvcNAQELBQADggEBAI39HR+PiNNl+LVcRumn
// SIG // 07Y/SstDBcIHDcNeA4QjN6h6jJcj/yechH1h61xLVz6b
// SIG // 9ETbgFj3tmXejxIKX6eHdLfaFECHUeyfSkdV8BfoGD5x
// SIG // IDHmKCKrTvaunGvC50T7aA0gf1M/lBuhhoJOMhYQWj+J
// SIG // WMHQtNu2kPuNMumhS0ZQN7bDOukpJBKSWk4rubYKejaM
// SIG // l8DviXwz3jHhoZfk50WtYVL9WonTVH6KTVuJew6Wd9Hy
// SIG // PDgb2vmlYSBlArzFrdcMYhAoLN2246hhAKwIJqONhdBk
// SIG // yTaQHopSyYeNNaVdSJH8k6alZfHs+TrcpSyeBG1iM/7e
// SIG // +p/Fzq+V81Go8s4wggQVMIIC/aADAgECAgsEAAAAAAEx
// SIG // icZQBDANBgkqhkiG9w0BAQsFADBMMSAwHgYDVQQLExdH
// SIG // bG9iYWxTaWduIFJvb3QgQ0EgLSBSMzETMBEGA1UEChMK
// SIG // R2xvYmFsU2lnbjETMBEGA1UEAxMKR2xvYmFsU2lnbjAe
// SIG // Fw0xMTA4MDIxMDAwMDBaFw0yOTAzMjkxMDAwMDBaMFsx
// SIG // CzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWdu
// SIG // IG52LXNhMTEwLwYDVQQDEyhHbG9iYWxTaWduIFRpbWVz
// SIG // dGFtcGluZyBDQSAtIFNIQTI1NiAtIEcyMIIBIjANBgkq
// SIG // hkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAqpuOw6sRUSUB
// SIG // tpaU4k/YwQj2RiPZRcWVl1urGr/SbFfJMwYfoA/GPH5T
// SIG // SHq/nYeer+7DjEfhQuzj46FKbAwXxKbBuc1b8R5EiY7+
// SIG // C94hWBPuTcjFZwscsrPxNHaRossHbTfFoEcmAhWkkJGp
// SIG // eZ7X61edK3wi2BTX8QceeCI2a3d5r6/5f45O4bUIMf3q
// SIG // 7UtxYowj8QM5j0R5tnYDV56tLwhG3NKMvPSOdM7IaGlR
// SIG // dhGLD10kWxlUPSbMQI2CJxtZIH1Z9pOAjvgqOP1roEBl
// SIG // H1d2zFuOBE8sqNuEUBNPxtyLufjdaUyI65x7MCb8eli7
// SIG // WbwUcpKBV7d2ydiACoBuCQIDAQABo4HoMIHlMA4GA1Ud
// SIG // DwEB/wQEAwIBBjASBgNVHRMBAf8ECDAGAQH/AgEAMB0G
// SIG // A1UdDgQWBBSSIadKlV1ksJu0HuYAN0fmnUErTDBHBgNV
// SIG // HSAEQDA+MDwGBFUdIAAwNDAyBggrBgEFBQcCARYmaHR0
// SIG // cHM6Ly93d3cuZ2xvYmFsc2lnbi5jb20vcmVwb3NpdG9y
// SIG // eS8wNgYDVR0fBC8wLTAroCmgJ4YlaHR0cDovL2NybC5n
// SIG // bG9iYWxzaWduLm5ldC9yb290LXIzLmNybDAfBgNVHSME
// SIG // GDAWgBSP8Et/qC5FJK5NUPpjmove4t0bvDANBgkqhkiG
// SIG // 9w0BAQsFAAOCAQEABFaCSnzQzsm/NmbRvjWek2yX6AbO
// SIG // MRhZ+WxBX4AuwEIluBjH/NSxN8RooM8oagN0S2OXhXdh
// SIG // O9cv4/W9M6KSfREfnops7yyw9GKNNnPRFjbxvF7stICY
// SIG // ePzSdnno4SGU4B/EouGqZ9uznHPlQCLPOc7b5neVp7uy
// SIG // y/YZhp2fyNSYBbJxb051rvE9ZGo7Xk5GpipdCJLxo/Md
// SIG // dL9iDSOMXCo4ldLA1c3PiNofKLW6gWlkKrWmotVzr9xG
// SIG // 2wSukdduxZi61EfEVnSAR3hYjL7vK/3sbL/RlPe/UOB7
// SIG // 4JD9IBh4GCJdCC6MHKCX8x2ZfaOdkdMGRE4EbnocIOM2
// SIG // 8LZQuTGCAqgwggKkAgEBMGswWzELMAkGA1UEBhMCQkUx
// SIG // GTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExMTAvBgNV
// SIG // BAMTKEdsb2JhbFNpZ24gVGltZXN0YW1waW5nIENBIC0g
// SIG // U0hBMjU2IC0gRzICDAynz10HBySsieeaOjANBglghkgB
// SIG // ZQMEAgEFAKCCAQ4wGgYJKoZIhvcNAQkDMQ0GCyqGSIb3
// SIG // DQEJEAEEMBwGCSqGSIb3DQEJBTEPFw0yMDAyMDcxNjE3
// SIG // MTBaMC8GCSqGSIb3DQEJBDEiBCDIdqf+9S/fGi24ynB+
// SIG // vhjXQHwW6atM3QzNWnzaH5rrGDCBoAYLKoZIhvcNAQkQ
// SIG // AgwxgZAwgY0wgYowgYcEFJsSBXrnKq/21jdytJ9qI28m
// SIG // Sc2pMG8wX6RdMFsxCzAJBgNVBAYTAkJFMRkwFwYDVQQK
// SIG // ExBHbG9iYWxTaWduIG52LXNhMTEwLwYDVQQDEyhHbG9i
// SIG // YWxTaWduIFRpbWVzdGFtcGluZyBDQSAtIFNIQTI1NiAt
// SIG // IEcyAgwMp89dBwckrInnmjowDQYJKoZIhvcNAQEBBQAE
// SIG // ggEAqKmmkRIVSB460Yi8z7Lc7u3vxOT3uhBuvVJuLsBm
// SIG // hyA5TOCHzVrbpP73fsVcL6FvxBZ5gSnISayG70JtZMLj
// SIG // +4sGLaGqOd/Qw3Wl3WDM1ZrQN+SGjIMEDNtzwzL0CZFT
// SIG // m5HbcP95NGgkItQ+oowvTzP7ip1JRYyrl8Xfck1JIAuI
// SIG // UWKK2m4o1c32HtQ5+5VNGo7XDsrNI/xN1edovNUafCwp
// SIG // vkT0X1qtFR1l6XQFooghb7BITnW9b7r6Ro0GRWl+nr7V
// SIG // u3S5jQI10HCGAiq3/fxM+lJBzqfeuuiu3Aq3vaKshk3v
// SIG // WwDTVaaaDEVo8sdH1GBmV81TNe9eBzwVx1V/vg==
// SIG // End signature block
