// ContextId data loader.
(function($) {
	$.widget('adsk.contextiddataloader', {
		options: {
		    config: {},
            path: 'scripts/',
            timeout: 5000
		},

		_scheduler: undefined,
		_loadedData: 0,
		_totalData: 0,
		_pendingData: {},

		/* Private members. */

		_create: function() {
            console.log('contextiddataloader: _create');

            this._scheduler = $.adsk.executionscheduler({
                timeout: this.options.timeout,
                expired: $.proxy(this._loadExpired, this)
            });
		},

		_getPathSetToLoad: function(book) {
		    console.log('contextiddataloader: _getPathSetToLoad');

            var that = this,
                path = this.options.path;

            if (book.htmlRootDir) {
                path = path.concat(book.htmlRootDir, "/");
            }

            var pathSet = [];

            $.each(book.files.js.contextIdEntries, function(index, entry) {
                if (entry && entry != '') {
                    pathSet.push(path.concat(entry));
                }
            });

            return pathSet;
		},

		_getBooksDataToLoad: function(books) {
		    console.log('contextiddataloader: _getBooksDataToLoad');

            var that = this;

            this._loadedData = 0;
            this._totalData = 0;

            $.each(books, function(index, book) {
                var bookName = book.htmlRootDir,
                    entryCount = book.files.js.contextIdEntries.length;

                that._totalData += entryCount;

                that._pendingData[bookName] = {
                    loaded: false,
                    bookName: bookName,
                    pathSet: that._getPathSetToLoad(book),
                    total: entryCount,
                    count: 0
                };
            });
		},

		_loadExpired: function() {
		    console.log('contextiddataloader: _loadExpired');

            for (var bookName in this._pendingData) {
                var data = this._pendingData[bookName];

                if (!data.loaded) {
                    this._loadedData++;

                    this._trigger('loaded', {}, {
                        bookName:   bookName,
                        bookData:   data,
                        loaded:     this._loadedData,
                        total:      this._totalData
                    });
                }
            }

            this._totalData = 0;
            this._loadedData = 0;
		},

		_setDataLoaded: function(bookName) {
		    console.log('contextiddataloader: _setDataLoaded');

		    var pendingData = this._pendingData[bookName];

            pendingData.count += 1;
            if (pendingData.count == pendingData.total) {
                pendingData.loaded = true;
            }

            this._loadedData++;
            this._scheduler.schedule();
        },

		_bindListener: function() {
		    console.log('contextiddataloader: _bindListener');

		    $(document).bind("register-contextid-entries", $.proxy(function(event, bookName, data) {
                this._setDataLoaded(bookName);

                this._trigger('loaded', event, {
                    bookName: bookName,
                    bookData: data,
                    loaded: this._loadedData,
                    total: this._totalData
                });
            }, this));
		},

		_getScriptLoadingFunction: function() {
		    console.log('contextiddataloader: _getScriptLoadingFunction');

		    if (document.location.hostname === 'localhost' || document.location.protocol === 'file:') {
		        console.log('contextiddataloader: _getScriptLoadingFunction (offline)');
		        return yepnope;
		    } else {
		        console.log('contextiddataloader: _getScriptLoadingFunction (online)');
		        return $.getScript;
		    }
		},

		_loadData: function() {
		    console.log('contextiddataloader: _loadData');

            this._scheduler.schedule();

            // Use either AJAX request for online or script tag insertion for offline use.
            var getScript = this._getScriptLoadingFunction();

            for (var bookName in this._pendingData) {
                var pendingData = this._pendingData[bookName];

                if (pendingData) {
                    var len = pendingData.pathSet.length, i, path;

                    for (i = 0; i < len; ++i) {
                        path = pendingData.pathSet[i];

                        if (path) {
                            getScript(path);
                        }
                    }
                }
            }
		},

		/* Public members. */

        loadContextIdData: function() {
            console.log('contextiddataloader: loadTocData');

            this._bindListener();

            this._getBooksDataToLoad(this.options.config.books);

            if (this._totalData > 0) {
                this._loadData();
            } else {
                this._trigger('loaded', null, {
                    bookName: null,
                    bookData: null,
                    loaded: 0,
                    total: 0
                });
            }
        }
	});
})(jQuery);
// SIG // Begin signature block
// SIG // MIIgdwYJKoZIhvcNAQcCoIIgaDCCIGQCAQExDzANBglg
// SIG // hkgBZQMEAgEFADB3BgorBgEEAYI3AgEEoGkwZzAyBgor
// SIG // BgEEAYI3AgEeMCQCAQEEEBDgyQbOONQRoqMAEEvTUJAC
// SIG // AQACAQACAQACAQACAQAwMTANBglghkgBZQMEAgEFAAQg
// SIG // bkW7VG54sbaua11DbgfZtxtlVlFm8z0zMui3wL7As3Gg
// SIG // ggoaMIIEyzCCA7OgAwIBAgIQCQja65wGHi65un4mqmKH
// SIG // ijANBgkqhkiG9w0BAQsFADCBhDELMAkGA1UEBhMCVVMx
// SIG // HTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9uMR8w
// SIG // HQYDVQQLExZTeW1hbnRlYyBUcnVzdCBOZXR3b3JrMTUw
// SIG // MwYDVQQDEyxTeW1hbnRlYyBDbGFzcyAzIFNIQTI1NiBD
// SIG // b2RlIFNpZ25pbmcgQ0EgLSBHMjAeFw0xOTA1MTQwMDAw
// SIG // MDBaFw0yMDA1MTMyMzU5NTlaMHwxCzAJBgNVBAYTAlVT
// SIG // MRMwEQYDVQQIDApDYWxpZm9ybmlhMRMwEQYDVQQHDApT
// SIG // YW4gUmFmYWVsMRcwFQYDVQQKDA5BdXRvZGVzaywgSW5j
// SIG // LjERMA8GA1UECwwIU2VjdXJpdHkxFzAVBgNVBAMMDkF1
// SIG // dG9kZXNrLCBJbmMuMIIBIjANBgkqhkiG9w0BAQEFAAOC
// SIG // AQ8AMIIBCgKCAQEAkVKRoPYsoxPdlabspcuG8HYDfcWQ
// SIG // 9qyPOT2punwpVdjt2slktcpSTlydrGy8ijcbl5/k8AOJ
// SIG // afKMQvow0fNjIoNB5nsb8j2xFJPbBhHl8GT4P6DZ1OWK
// SIG // ioiUXgGHKjctUws49J4elntqvBYhKCbuPqG772QCoYFU
// SIG // P7qcFbh3PbyNB6cnKMn2vNGRqiEtV2aGg+/MiL3QPsvT
// SIG // kTWhVuTLIvwZ4kK5C5ACiQzlGOlE+C7gWuFoxtvy6gUa
// SIG // A8JAq/xLjYKwFevQwGncg3s1cuiGhx0P7Rvn6oCd2cem
// SIG // FmbK3I3rMRt+jc9wzAj3oHxvCo4f5Lfva+OpC1dETUVV
// SIG // sk0VGwIDAQABo4IBPjCCATowCQYDVR0TBAIwADAOBgNV
// SIG // HQ8BAf8EBAMCB4AwEwYDVR0lBAwwCgYIKwYBBQUHAwMw
// SIG // YQYDVR0gBFowWDBWBgZngQwBBAEwTDAjBggrBgEFBQcC
// SIG // ARYXaHR0cHM6Ly9kLnN5bWNiLmNvbS9jcHMwJQYIKwYB
// SIG // BQUHAgIwGQwXaHR0cHM6Ly9kLnN5bWNiLmNvbS9ycGEw
// SIG // HwYDVR0jBBgwFoAU1MAGIknrOUvdk+JcobhHdglyA1gw
// SIG // KwYDVR0fBCQwIjAgoB6gHIYaaHR0cDovL3JiLnN5bWNi
// SIG // LmNvbS9yYi5jcmwwVwYIKwYBBQUHAQEESzBJMB8GCCsG
// SIG // AQUFBzABhhNodHRwOi8vcmIuc3ltY2QuY29tMCYGCCsG
// SIG // AQUFBzAChhpodHRwOi8vcmIuc3ltY2IuY29tL3JiLmNy
// SIG // dDANBgkqhkiG9w0BAQsFAAOCAQEA0Q2+iVSEfT4xGq3A
// SIG // OADVb0rT5Z8E+PPb1x6hKknSzuaZKk/acDz9mdnFajaU
// SIG // WgIKiFJlsqJnuAM1w4lqKaEWsz3DoxvGIEwexj71Ud6a
// SIG // KlBJNcR9DdkXUZwMhbw9d78rjJAIX6tOwfSludZfdq8b
// SIG // YEkuIzQi9uYW9vHVPSCzhnUBKjwc9qTo9yBc7Fcn4FAT
// SIG // 90DzWM2hS9oc3p0pprYI2I/O4th90BEmwWkVqVgfaR0z
// SIG // VyIEmBbqB/IWLfjUBZJ/8sbkwWuWlYVRrfPxsj1e9qvb
// SIG // wE3Y28jWyGbqoUG39GhXk3uT8R8i3+T6M0c4rMfdifBC
// SIG // pceCaFTJzSye7LoeVzCCBUcwggQvoAMCAQICEHwbNTVK
// SIG // 59t050FfEWnKa6gwDQYJKoZIhvcNAQELBQAwgb0xCzAJ
// SIG // BgNVBAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5j
// SIG // LjEfMB0GA1UECxMWVmVyaVNpZ24gVHJ1c3QgTmV0d29y
// SIG // azE6MDgGA1UECxMxKGMpIDIwMDggVmVyaVNpZ24sIElu
// SIG // Yy4gLSBGb3IgYXV0aG9yaXplZCB1c2Ugb25seTE4MDYG
// SIG // A1UEAxMvVmVyaVNpZ24gVW5pdmVyc2FsIFJvb3QgQ2Vy
// SIG // dGlmaWNhdGlvbiBBdXRob3JpdHkwHhcNMTQwNzIyMDAw
// SIG // MDAwWhcNMjQwNzIxMjM1OTU5WjCBhDELMAkGA1UEBhMC
// SIG // VVMxHTAbBgNVBAoTFFN5bWFudGVjIENvcnBvcmF0aW9u
// SIG // MR8wHQYDVQQLExZTeW1hbnRlYyBUcnVzdCBOZXR3b3Jr
// SIG // MTUwMwYDVQQDEyxTeW1hbnRlYyBDbGFzcyAzIFNIQTI1
// SIG // NiBDb2RlIFNpZ25pbmcgQ0EgLSBHMjCCASIwDQYJKoZI
// SIG // hvcNAQEBBQADggEPADCCAQoCggEBANeVQ9Tc32euOftS
// SIG // pLYmMQRw6beOWyq6N2k1lY+7wDDnhthzu9/r0XY/ilaO
// SIG // 6y1L8FcYTrGNpTPTC3Uj1Wp5J92j0/cOh2W13q0c8fU1
// SIG // tCJRryKhwV1LkH/AWU6rnXmpAtceSbE7TYf+wnirv+9S
// SIG // rpyvCNk55ZpRPmlfMBBOcWNsWOHwIDMbD3S+W8sS4duM
// SIG // xICUcrv2RZqewSUL+6McntimCXBx7MBHTI99w94Zzj7u
// SIG // BHKOF9P/8LIFMhlM07Acn/6leCBCcEGwJoxvAMg6ABFB
// SIG // ekGwp4qRBKCZePR3tPNgKuZsUAS3FGD/DVH0qIuE/iHa
// SIG // XF599Sl5T7BEdG9tcv8CAwEAAaOCAXgwggF0MC4GCCsG
// SIG // AQUFBwEBBCIwIDAeBggrBgEFBQcwAYYSaHR0cDovL3Mu
// SIG // c3ltY2QuY29tMBIGA1UdEwEB/wQIMAYBAf8CAQAwZgYD
// SIG // VR0gBF8wXTBbBgtghkgBhvhFAQcXAzBMMCMGCCsGAQUF
// SIG // BwIBFhdodHRwczovL2Quc3ltY2IuY29tL2NwczAlBggr
// SIG // BgEFBQcCAjAZGhdodHRwczovL2Quc3ltY2IuY29tL3Jw
// SIG // YTA2BgNVHR8ELzAtMCugKaAnhiVodHRwOi8vcy5zeW1j
// SIG // Yi5jb20vdW5pdmVyc2FsLXJvb3QuY3JsMBMGA1UdJQQM
// SIG // MAoGCCsGAQUFBwMDMA4GA1UdDwEB/wQEAwIBBjApBgNV
// SIG // HREEIjAgpB4wHDEaMBgGA1UEAxMRU3ltYW50ZWNQS0kt
// SIG // MS03MjQwHQYDVR0OBBYEFNTABiJJ6zlL3ZPiXKG4R3YJ
// SIG // cgNYMB8GA1UdIwQYMBaAFLZ3+mlIR59TEtXC6gcydgfR
// SIG // lwcZMA0GCSqGSIb3DQEBCwUAA4IBAQB/68qn6ot2Qus+
// SIG // jiBUMOO3udz6SD4Wxw9FlRDNJ4ajZvMC7XH4qsJVl5Fw
// SIG // g/lSflJpPMnx4JRGgBi7odSkVqbzHQCR1YbzSIfgy8Q0
// SIG // aCBetMv5Be2cr3BTJ7noPn5RoGlxi9xR7YA6JTKfRK9u
// SIG // QyjTIXW7l9iLi4z+qQRGBIX3FZxLEY3ELBf+1W5/muJW
// SIG // kvGWs60t+fTf2omZzrI4RMD3R3vKJbn6Kmgzm1By3qif
// SIG // 1M0sCzS9izB4QOCNjicbkG8avggVgV3rL+JR51EeyXgp
// SIG // 5x5lvzjvAUoBCSQOFsQUecFBNzTQPZFSlJ3haO8I8OJp
// SIG // nGdukAsak3HUJgLDwFojMYIVtTCCFbECAQEwgZkwgYQx
// SIG // CzAJBgNVBAYTAlVTMR0wGwYDVQQKExRTeW1hbnRlYyBD
// SIG // b3Jwb3JhdGlvbjEfMB0GA1UECxMWU3ltYW50ZWMgVHJ1
// SIG // c3QgTmV0d29yazE1MDMGA1UEAxMsU3ltYW50ZWMgQ2xh
// SIG // c3MgMyBTSEEyNTYgQ29kZSBTaWduaW5nIENBIC0gRzIC
// SIG // EAkI2uucBh4uubp+Jqpih4owDQYJYIZIAWUDBAIBBQCg
// SIG // fDAQBgorBgEEAYI3AgEMMQIwADAZBgkqhkiG9w0BCQMx
// SIG // DAYKKwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYK
// SIG // KwYBBAGCNwIBFTAvBgkqhkiG9w0BCQQxIgQgAr+QjV0L
// SIG // /b3fybI8Qd8TXHuPdZpwM6kCq3gGOIUnYxAwDQYJKoZI
// SIG // hvcNAQEBBQAEggEAh+rQPwMzLWMVv9CjU9Wi13e8DPEz
// SIG // e+WaIVJObyUa7GxBXz8iK5Uqz3BJvUIFCS2MjM7ixpTc
// SIG // HYPKh2ZESDFFBd/lD/Kuvrc+fd9t032EMFhrjlQ7LXGb
// SIG // IL9DdKCEz3j4NW4dowup+U3tNuRQtwF3OKXsjP32tXyK
// SIG // W8byiS9dSV7M6icpSGCSIhzPA1XVOhv+7ny4t8t8j4X2
// SIG // aCw8M3eIoAWv2doYSooZfC4x89M/7MSbgRkn85rhMTlI
// SIG // EMNHXYSYZYCFFZGv7x+jdRfR44WITNIUNJb0fu0s22I3
// SIG // eB7HjmSVU1RA6gXZIeyo0GXPoZnf6nDf4+Q6s8LUCUg8
// SIG // P1dJiKGCE24wghNqBgorBgEEAYI3AwMBMYITWjCCE1YG
// SIG // CSqGSIb3DQEHAqCCE0cwghNDAgEDMQ8wDQYJYIZIAWUD
// SIG // BAIBBQAwggENBgsqhkiG9w0BCRABBKCB/QSB+jCB9wIB
// SIG // AQYKKwYBBAGyMQIBATAxMA0GCWCGSAFlAwQCAQUABCBB
// SIG // rNkd2WZ1S6VusymAMd0Z43nQ7BPuwA4t1H5LgNmvmwIV
// SIG // AKR3QeGWHzDT2KXP4dqsm1oEJ8RIGA8yMDIwMDIwNzE2
// SIG // MTc1NlqggYqkgYcwgYQxCzAJBgNVBAYTAkdCMRswGQYD
// SIG // VQQIDBJHcmVhdGVyIE1hbmNoZXN0ZXIxEDAOBgNVBAcM
// SIG // B1NhbGZvcmQxGDAWBgNVBAoMD1NlY3RpZ28gTGltaXRl
// SIG // ZDEsMCoGA1UEAwwjU2VjdGlnbyBSU0EgVGltZSBTdGFt
// SIG // cGluZyBTaWduZXIgIzGggg36MIIHBjCCBO6gAwIBAgIQ
// SIG // PRo1cjAVgmMw0BNxfoJBCDANBgkqhkiG9w0BAQwFADB9
// SIG // MQswCQYDVQQGEwJHQjEbMBkGA1UECBMSR3JlYXRlciBN
// SIG // YW5jaGVzdGVyMRAwDgYDVQQHEwdTYWxmb3JkMRgwFgYD
// SIG // VQQKEw9TZWN0aWdvIExpbWl0ZWQxJTAjBgNVBAMTHFNl
// SIG // Y3RpZ28gUlNBIFRpbWUgU3RhbXBpbmcgQ0EwHhcNMTkw
// SIG // NTAyMDAwMDAwWhcNMzAwODAxMjM1OTU5WjCBhDELMAkG
// SIG // A1UEBhMCR0IxGzAZBgNVBAgMEkdyZWF0ZXIgTWFuY2hl
// SIG // c3RlcjEQMA4GA1UEBwwHU2FsZm9yZDEYMBYGA1UECgwP
// SIG // U2VjdGlnbyBMaW1pdGVkMSwwKgYDVQQDDCNTZWN0aWdv
// SIG // IFJTQSBUaW1lIFN0YW1waW5nIFNpZ25lciAjMTCCAiIw
// SIG // DQYJKoZIhvcNAQEBBQADggIPADCCAgoCggIBAMtRUP9W
// SIG // /vx4Y3ABk1qeGPQ7U/YHryFs9aIPfR1wLYR0SIucipUF
// SIG // PVmE+ZGAeVEs2Yq3wQuaugqKzWZPA4sBuzDKq73bwE8S
// SIG // XvwKzOJFsAE4irtN59QcVJjtOVjPW8IvRZgxCvk1OLgx
// SIG // Lm20Hjly4bgqvp+MjBqlRq4LK0yZ/ixL/Ci5IjpmF9Cq
// SIG // VoohwPOWJLTQhSZruvBvZJh5pq29XNhTaysK1nKKhUbj
// SIG // DRgG2sZ7QVY2mxU+8WoRoPdm9RjQgFVjh2hm6w55VYJc
// SIG // o+1JuHGGnpM3sGuj6mJso66W6Ln9i6vG9llbADxXIBgt
// SIG // cAOnnO+S63mhx13sfLSPS9/rXfyjIN2SOOVqUTprhZxM
// SIG // oJgIaVsG5yoZ0JWTiztrigUJKdjW2tvjcvpcSi97FVaG
// SIG // Mr9/BQmdLSrPUOHmYSDbxwaAXE4URr6uV3Giqmwwkxx+
// SIG // d8sG6VfNkfXVM3Ic4drKbuvzD+x5W7snnuge/i/yu3/p
// SIG // 5dBn67gNfKQrWQOLle0iKM36LDvHFhGv49axUGdpxY71
// SIG // edCt/4fM+H+q+aLtYfjIjWnasfRRketnV9FkEetkywO9
// SIG // SVU6RUMYLCVs0S8MLW/1QTUkoPJjWRZf2aTpLE7buzES
// SIG // xm34W24D3MsVjxuNcuzbDxWQ1hJO7uIAMSWTNW9qW6US
// SIG // Y0ABirlpiDqIuA8ZAgMBAAGjggF4MIIBdDAfBgNVHSME
// SIG // GDAWgBQaofhhGSAPw0F3RSiO0TVfBhIEVTAdBgNVHQ4E
// SIG // FgQUb02GB9gyJ54sKdLQEwOAgd0FgykwDgYDVR0PAQH/
// SIG // BAQDAgbAMAwGA1UdEwEB/wQCMAAwFgYDVR0lAQH/BAww
// SIG // CgYIKwYBBQUHAwgwQAYDVR0gBDkwNzA1BgwrBgEEAbIx
// SIG // AQIBAwgwJTAjBggrBgEFBQcCARYXaHR0cHM6Ly9zZWN0
// SIG // aWdvLmNvbS9DUFMwRAYDVR0fBD0wOzA5oDegNYYzaHR0
// SIG // cDovL2NybC5zZWN0aWdvLmNvbS9TZWN0aWdvUlNBVGlt
// SIG // ZVN0YW1waW5nQ0EuY3JsMHQGCCsGAQUFBwEBBGgwZjA/
// SIG // BggrBgEFBQcwAoYzaHR0cDovL2NydC5zZWN0aWdvLmNv
// SIG // bS9TZWN0aWdvUlNBVGltZVN0YW1waW5nQ0EuY3J0MCMG
// SIG // CCsGAQUFBzABhhdodHRwOi8vb2NzcC5zZWN0aWdvLmNv
// SIG // bTANBgkqhkiG9w0BAQwFAAOCAgEAwGjts9jUUJvv03XL
// SIG // Dzv3JNN6N0WNLO8W+1GpLB+1JbWKn10LwhsgdI1mDzbL
// SIG // qvY2DQ9+j0tKdENlrA0q9grta23FCTjtABv45dymCkAF
// SIG // R++Eygm8Q2aDv5/t24490UFksXACLQNXWxhvHCzLHrIA
// SIG // 6LoJL1uBBDW5qWNtjgjFGNHhIaz5EgoUwBLbfiWdrB0Q
// SIG // wFqlg9IfGmZV/Jsq4uw3V47l35Yw+MCTC0MY+QJvqVGv
// SIG // uFcK8xwHaTmPN5xt15GupS5J6Ures9CMvzmQDcCBzvAq
// SIG // BzoMpi1R0nLzU8b5ve/vDGlJd58sVsTpoQg9B67FHtaE
// SIG // Ise8fUMbWDhiTtEFJYTFQvgfL/bb+quMVOxFimwSTTBa
// SIG // UuWkFwki5u9v9V+GQ9+hLb1KRpKggZYsYZd/QG/YP4w1
// SIG // WqvRxqA7hWZUgO8fGvXxm7ChJ32y5wvP9i2cWBOUqYb8
// SIG // RVKiKG1/dA9SkUl66RL4qTuwkv19kRTpW21IlPLIlu4F
// SIG // OLPF7DA/4QcgBLHYi7z9sz5v8gJTBvSg7cmacqOXXwD7
// SIG // y2PQ6M10/XXJ1DZFunsSWXLt5/J6UAB4+EOaRtjfv1TU
// SIG // XrHH0bwbg/Qr5wvoR8hTnswarPb6inVTbCCFqdW4arok
// SIG // joorCJGfNwQc9m+i3TSqkf/GFS4eQhoJKU/0xs3ikaLT
// SIG // QAyOeOMwggbsMIIE1KADAgECAhAwD2+s3WaYdHypRjan
// SIG // eC25MA0GCSqGSIb3DQEBDAUAMIGIMQswCQYDVQQGEwJV
// SIG // UzETMBEGA1UECBMKTmV3IEplcnNleTEUMBIGA1UEBxML
// SIG // SmVyc2V5IENpdHkxHjAcBgNVBAoTFVRoZSBVU0VSVFJV
// SIG // U1QgTmV0d29yazEuMCwGA1UEAxMlVVNFUlRydXN0IFJT
// SIG // QSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eTAeFw0xOTA1
// SIG // MDIwMDAwMDBaFw0zODAxMTgyMzU5NTlaMH0xCzAJBgNV
// SIG // BAYTAkdCMRswGQYDVQQIExJHcmVhdGVyIE1hbmNoZXN0
// SIG // ZXIxEDAOBgNVBAcTB1NhbGZvcmQxGDAWBgNVBAoTD1Nl
// SIG // Y3RpZ28gTGltaXRlZDElMCMGA1UEAxMcU2VjdGlnbyBS
// SIG // U0EgVGltZSBTdGFtcGluZyBDQTCCAiIwDQYJKoZIhvcN
// SIG // AQEBBQADggIPADCCAgoCggIBAMgbAa/ZLH6ImX0BmD8g
// SIG // kL2cgCFUk7nPoD5T77NawHbWGgSlzkeDtevEzEk0y/NF
// SIG // Zbn5p2QWJgn71TJSeS7JY8ITm7aGPwEFkmZvIavVcRB5
// SIG // h/RGKs3EWsnb111JTXJWD9zJ41OYOioe/M5YSdO/8zm7
// SIG // uaQjQqzQFcN/nqJc1zjxFrJw06PE37PFcqwuCnf8DZRS
// SIG // t/wflXMkPQEovA8NT7ORAY5unSd1VdEXOzQhe5cBlK9/
// SIG // gM/REQpXhMl/VuC9RpyCvpSdv7QgsGB+uE31DT/b0OqF
// SIG // jIpWcdEtlEzIjDzTFKKcvSb/01Mgx2Bpm1gKVPQF5/0x
// SIG // rPnIhRfHuCkZpCkvRuPd25Ffnz82Pg4wZytGtzWvlr7a
// SIG // TGDMqLufDRTUGMQwmHSCIc9iVrUhcxIe/arKCFiHd6QV
// SIG // 6xlV/9A5VC0m7kUaOm/N14Tw1/AoxU9kgwLU++Le8bwC
// SIG // KPRt2ieKBtKWh97oaw7wW33pdmmTIBxKlyx3GSuTlZic
// SIG // l57rjsF4VsZEJd8GEpoGLZ8DXv2DolNnyrH6jaFkyYiS
// SIG // WcuoRsDJ8qb/fVfbEnb6ikEk1Bv8cqUUotStQxykSYtB
// SIG // ORQDHin6G6UirqXDTYLQjdprt9v3GEBXc/Bxo/tKfUU2
// SIG // wfeNgvq5yQ1TgH36tjlYMu9vGFCJ10+dM70atZ2h3pVB
// SIG // eqeDAgMBAAGjggFaMIIBVjAfBgNVHSMEGDAWgBRTeb9a
// SIG // qitKz1SA4dibwJ3ysgNmyzAdBgNVHQ4EFgQUGqH4YRkg
// SIG // D8NBd0UojtE1XwYSBFUwDgYDVR0PAQH/BAQDAgGGMBIG
// SIG // A1UdEwEB/wQIMAYBAf8CAQAwEwYDVR0lBAwwCgYIKwYB
// SIG // BQUHAwgwEQYDVR0gBAowCDAGBgRVHSAAMFAGA1UdHwRJ
// SIG // MEcwRaBDoEGGP2h0dHA6Ly9jcmwudXNlcnRydXN0LmNv
// SIG // bS9VU0VSVHJ1c3RSU0FDZXJ0aWZpY2F0aW9uQXV0aG9y
// SIG // aXR5LmNybDB2BggrBgEFBQcBAQRqMGgwPwYIKwYBBQUH
// SIG // MAKGM2h0dHA6Ly9jcnQudXNlcnRydXN0LmNvbS9VU0VS
// SIG // VHJ1c3RSU0FBZGRUcnVzdENBLmNydDAlBggrBgEFBQcw
// SIG // AYYZaHR0cDovL29jc3AudXNlcnRydXN0LmNvbTANBgkq
// SIG // hkiG9w0BAQwFAAOCAgEAbVSBpTNdFuG1U4GRdd8DejIL
// SIG // LSWEEbKw2yp9KgX1vDsn9FqguUlZkClsYcu1UNviffmf
// SIG // AO9Aw63T4uRW+VhBz/FC5RB9/7B0H4/GXAn5M17qoBwm
// SIG // WFzztBEP1dXD4rzVWHi/SHbhRGdtj7BDEA+N5Pk4Yr8T
// SIG // AcWFo0zFzLJTMJWk1vSWVgi4zVx/AZa+clJqO0I3fBZ4
// SIG // OZOTlJux3LJtQW1nzclvkD1/RXLBGyPWwlWEZuSzxWYG
// SIG // 9vPWS16toytCiiGS/qhvWiVwYoFzY16gu9jc10rTPa+D
// SIG // BjgSHSSHLeT8AtY+dwS8BDa153fLnC6NIxi5o8JHHfBd
// SIG // 1qFzVwVomqfJN2Udvuq82EKDQwWli6YJ/9GhlKZOqj0J
// SIG // 9QVst9JkWtgqIsJLnfE5XkzeSD2bNJaaCV+O/fexUpHO
// SIG // P4n2HKG1qXUfcb9bQ11lPVCBbqvw0NP8srMftpmWJvQ8
// SIG // eYtcZMzN7iea5aDADHKHwW5NWtMe6vBE5jJvHOsXTpTD
// SIG // eGUgOw9Bqh/poUGd/rG4oGUqNODeqPk85sEwu8CgYyz8
// SIG // XBYAqNDEf+oRnR4GxqZtMl20OAkrSQeq/eww2vGnL8+3
// SIG // /frQo4TZJ577AWZ3uVYQ4SBuxq6x+ba6yDVdM3aO8Xwg
// SIG // DCp3rrWiAoa6Ke60WgCxjKvj+QrJVF3UuWp0nr1Irpgx
// SIG // ggQcMIIEGAIBATCBkTB9MQswCQYDVQQGEwJHQjEbMBkG
// SIG // A1UECBMSR3JlYXRlciBNYW5jaGVzdGVyMRAwDgYDVQQH
// SIG // EwdTYWxmb3JkMRgwFgYDVQQKEw9TZWN0aWdvIExpbWl0
// SIG // ZWQxJTAjBgNVBAMTHFNlY3RpZ28gUlNBIFRpbWUgU3Rh
// SIG // bXBpbmcgQ0ECED0aNXIwFYJjMNATcX6CQQgwDQYJYIZI
// SIG // AWUDBAIBBQCgggFbMBoGCSqGSIb3DQEJAzENBgsqhkiG
// SIG // 9w0BCRABBDAcBgkqhkiG9w0BCQUxDxcNMjAwMjA3MTYx
// SIG // NzU2WjAvBgkqhkiG9w0BCQQxIgQg1HFCd9PQyN5ZTc0v
// SIG // U61UQi/3B+tGzu5r1DaHzxR2itUwge0GCyqGSIb3DQEJ
// SIG // EAIMMYHdMIHaMIHXMBYEFCXIrHNOSFC3+NkTkagbkkk2
// SIG // ZZ9hMIG8BBQC1luV4oNwwVcAlfqI+SPdk3+tjzCBozCB
// SIG // jqSBizCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCk5l
// SIG // dyBKZXJzZXkxFDASBgNVBAcTC0plcnNleSBDaXR5MR4w
// SIG // HAYDVQQKExVUaGUgVVNFUlRSVVNUIE5ldHdvcmsxLjAs
// SIG // BgNVBAMTJVVTRVJUcnVzdCBSU0EgQ2VydGlmaWNhdGlv
// SIG // biBBdXRob3JpdHkCEDAPb6zdZph0fKlGNqd4LbkwDQYJ
// SIG // KoZIhvcNAQEBBQAEggIAXgelXYbw2cyZVbwUn6KUNdY9
// SIG // DjjmWlbXKfZm0We3xcuapRMHMrauL6JaeU6EHliqFg/m
// SIG // gIzx+KRQ/Xeox+5rjg0IuNi9Cpmvhp5CNYeiQ+IRlXJE
// SIG // KU8u9d1wp5pZguliJLlaQMWEjt+e/b+cVGAg2l6ev4mU
// SIG // ltnaATxFlSDE1yI/psO59R+1KzPbzPBedsB347KnmYRk
// SIG // 6b1eZw9hVZBX5h8XlrDh4JxnlQfo/IcCRw7vwPT2xftF
// SIG // sJgzE740E3bOQtcHX1LAqaDEeXoozBDLMmBMmnlxpr42
// SIG // C5An2572DutQlQGEzVAxXsNbpoFS9IK8Q3B/t9Ewn/sL
// SIG // ChvmtHzd+C18aHslwJz+MTLdLfHM91BC89umI2mm0lyJ
// SIG // lde+DB8UJjJO974qDk/bwEaOV/DUdh6awZI52MbRJRmK
// SIG // 6ko/iJlNu5XGhPNOzU2A6b3RhY/UN5A5EQ9tuorZ3apf
// SIG // NEA/r9MnghKdd70Lul1ZSB6k0Tw80lfT46kefR35SMXA
// SIG // YT/mrkDE7biOBvtXp/t6/ZQBXGL/bs9DPP/v1nkExqaj
// SIG // aaETlYqeNQWucZYpLFQgbWN55rbva4bsd9wjgKq1//Ds
// SIG // IuQwvZxbo5qn721gxIguZmS4BU+2t4B8nWFUd1iJJ+tk
// SIG // MBHq5nFJrmp0pP5nEU0muOVyZLUKjGFVulhtglwb5Xg=
// SIG // End signature block
